@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
+# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
 # SPDX-License-Identifier: Apache-2.0
 # type: ignore
 
@@ -704,7 +704,7 @@ class PrettyPrintBase(PackageVisitor[str], ModuleVisitor[str], ExprVisitor[str],
     def visit_type_forall(self, forall: "Type.Forall") -> "str":
         pass
 
-    def visit_type_tuple(self, tuple: "Type.Tuple") -> "str":
+    def visit_type_struct(self, struct: "Type.Struct") -> "str":
         pass
 
     def visit_type_nat(self, nat: int) -> "str":
